@@ -3,14 +3,12 @@ use std::ops::{Deref, DerefMut};
 
 use ahash::RandomState;
 
-use super::private;
-use super::IntoSeries;
-use super::SeriesTrait;
-use super::SeriesWrap;
-use super::*;
-use crate::chunked_array::{ops::explode::ExplodeByOffsets, AsSinglePtr};
+use super::{private, IntoSeries, SeriesTrait, SeriesWrap, *};
+use crate::chunked_array::ops::explode::ExplodeByOffsets;
+use crate::chunked_array::AsSinglePtr;
 use crate::fmt::FmtList;
-use crate::frame::{groupby::*, hash_join::*};
+use crate::frame::groupby::*;
+use crate::frame::hash_join::*;
 use crate::prelude::*;
 
 impl IntoSeries for DatetimeChunked {
