@@ -1,9 +1,7 @@
-use std::path::Path;
-use std::path::PathBuf;
+use std::path::{Path, PathBuf};
 
 use polars_core::prelude::*;
-use polars_io::csv::utils::get_reader_bytes;
-use polars_io::csv::utils::infer_file_schema;
+use polars_io::csv::utils::{get_reader_bytes, infer_file_schema};
 use polars_io::csv::{CsvEncoding, NullValues};
 use polars_io::RowCount;
 
