@@ -41,22 +41,22 @@ use serde::{Deserialize, Serialize};
 use crate::logical_plan::optimizer::aggregate_pushdown::AggregatePushdown;
 #[cfg(any(feature = "parquet", feature = "csv-file", feature = "ipc"))]
 use crate::logical_plan::optimizer::file_caching::FileCacher;
+use crate::logical_plan::optimizer::predicate_pushdown::PredicatePushDown;
+use crate::logical_plan::optimizer::projection_pushdown::ProjectionPushDown;
 use crate::logical_plan::optimizer::simplify_expr::SimplifyExprRule;
 use crate::logical_plan::optimizer::stack_opt::{OptimizationRule, StackOptimizer};
-use crate::logical_plan::optimizer::{
-    predicate_pushdown::PredicatePushDown, projection_pushdown::ProjectionPushDown,
-};
 use crate::logical_plan::FETCH_ROWS;
 use crate::physical_plan::state::ExecutionState;
 use crate::prelude::delay_rechunk::DelayRechunk;
+use crate::prelude::drop_nulls::ReplaceDropNulls;
+use crate::prelude::fast_projection::FastProjection;
 #[cfg(any(feature = "ipc", feature = "parquet", feature = "csv-file"))]
 use crate::prelude::file_caching::collect_fingerprints;
 #[cfg(any(feature = "ipc", feature = "parquet", feature = "csv-file"))]
 use crate::prelude::file_caching::find_column_union_and_fingerprints;
-use crate::prelude::{
-    drop_nulls::ReplaceDropNulls, fast_projection::FastProjection,
-    simplify_expr::SimplifyBooleanRule, slice_pushdown_lp::SlicePushDown, *,
-};
+use crate::prelude::simplify_expr::SimplifyBooleanRule;
+use crate::prelude::slice_pushdown_lp::SlicePushDown;
+use crate::prelude::*;
 use crate::utils::{combine_predicates_expr, expr_to_root_column_names};
 
 #[derive(Clone, Debug)]
@@ -457,14 +457,26 @@ impl LazyFrame {
             .into_iter()
             .map(|a| a.as_ref().to_string())
             .collect::<Vec<_>>();
-        // todo! make delayed
-        let schema = &*self.schema().unwrap();
-        // a column gets swapped
-        if new.iter().any(|name| schema.get(name).is_some()) {
-            self.rename_impl_swapping(existing, new)
-        } else {
-            self.rename_impl(existing, new)
+
+        fn inner(lf: LazyFrame, existing: Vec<String>, new: Vec<String>) -> LazyFrame {
+            // remove mappings that map to themselves.
+            let (existing, new): (Vec<_>, Vec<_>) = existing
+                .into_iter()
+                .zip(new)
+                .flat_map(|(a, b)| if a == b { None } else { Some((a, b)) })
+                .unzip();
+
+            // todo! make delayed
+            let schema = &*lf.schema().unwrap();
+            // a column gets swapped
+            if new.iter().any(|name| schema.get(name).is_some()) {
+                lf.rename_impl_swapping(existing, new)
+            } else {
+                lf.rename_impl(existing, new)
+            }
         }
+
+        inner(self, existing, new)
     }
 
     /// Removes columns from the DataFrame.
@@ -687,9 +699,9 @@ impl LazyFrame {
     pub fn collect(self) -> Result<DataFrame> {
         let file_caching = self.opt_state.file_caching;
         #[cfg(feature = "dtype-categorical")]
-        let use_string_cache = self.opt_state.global_string_cache;
+        let using_string_cache = self.opt_state.global_string_cache;
         #[cfg(feature = "dtype-categorical")]
-        if use_string_cache {
+        if using_string_cache {
             eprint!("global string cache in combination with LazyFrames is deprecated; please set the global string cache globally.")
         }
         let mut expr_arena = Arena::with_capacity(256);
@@ -698,8 +710,8 @@ impl LazyFrame {
 
         // if string cache was already set, we skip this and global settings are respected
         #[cfg(feature = "dtype-categorical")]
-        if use_string_cache {
-            toggle_string_cache(use_string_cache);
+        if using_string_cache {
+            toggle_string_cache(using_string_cache);
         }
 
         let finger_prints = if file_caching {
@@ -729,8 +741,8 @@ impl LazyFrame {
             state.file_cache.assert_empty();
         }
         #[cfg(feature = "dtype-categorical")]
-        if use_string_cache {
-            toggle_string_cache(!use_string_cache);
+        if using_string_cache {
+            toggle_string_cache(!using_string_cache);
         }
         out
     }
