@@ -4,7 +4,7 @@ use std::path::PathBuf;
 use parking_lot::Mutex;
 use polars_core::frame::explode::MeltArgs;
 use polars_core::prelude::*;
-use polars_core::utils::get_supertype;
+use polars_core::utils::try_get_supertype;
 #[cfg(feature = "csv-file")]
 use polars_io::csv::utils::infer_file_schema;
 use polars_io::csv::CsvEncoding;
@@ -521,7 +521,17 @@ impl LogicalPlanBuilder {
             into
         );
 
-        let schema = det_join_schema(&schema_left, &schema_right, &right_names, &options);
+        let schema = try_delayed!(
+            det_join_schema(
+                &schema_left,
+                &schema_right,
+                &left_on,
+                &right_names,
+                &options
+            ),
+            self.0,
+            into
+        );
 
         LogicalPlan::Join {
             input_left: Box::new(self.0),
@@ -588,7 +598,7 @@ pub(crate) fn det_melt_schema(args: &MeltArgs, input_schema: &Schema) -> SchemaR
             if !id_vars.contains(name) {
                 match &st {
                     None => st = Some(dtype.clone()),
-                    Some(st_) => st = Some(get_supertype(st_, dtype).unwrap()),
+                    Some(st_) => st = Some(try_get_supertype(st_, dtype).unwrap()),
                 }
             }
         }
@@ -597,7 +607,7 @@ pub(crate) fn det_melt_schema(args: &MeltArgs, input_schema: &Schema) -> SchemaR
             let dtype = input_schema.get(name).unwrap();
             match &st {
                 None => st = Some(dtype.clone()),
-                Some(st_) => st = Some(get_supertype(st_, dtype).unwrap()),
+                Some(st_) => st = Some(try_get_supertype(st_, dtype).unwrap()),
             }
         }
     }
