@@ -9,9 +9,6 @@ fn to_aexprs(input: Vec<Expr>, arena: &mut Arena<AExpr>) -> Vec<Node> {
 /// converts expression to AExpr and adds it to the arena, which uses an arena (Vec) for allocation
 pub(crate) fn to_aexpr(expr: Expr, arena: &mut Arena<AExpr>) -> Node {
     let v = match expr {
-        Expr::IsUnique(expr) => AExpr::IsUnique(to_aexpr(*expr, arena)),
-        Expr::Duplicated(expr) => AExpr::Duplicated(to_aexpr(*expr, arena)),
-        Expr::Reverse(expr) => AExpr::Reverse(to_aexpr(*expr, arena)),
         Expr::Explode(expr) => AExpr::Explode(to_aexpr(*expr, arena)),
         Expr::Alias(e, name) => AExpr::Alias(to_aexpr(*e, arena), name),
         Expr::Literal(value) => AExpr::Literal(value),
@@ -25,10 +22,6 @@ pub(crate) fn to_aexpr(expr: Expr, arena: &mut Arena<AExpr>) -> Node {
                 right: r,
             }
         }
-        Expr::Not(e) => AExpr::Not(to_aexpr(*e, arena)),
-        Expr::IsNotNull(e) => AExpr::IsNotNull(to_aexpr(*e, arena)),
-        Expr::IsNull(e) => AExpr::IsNull(to_aexpr(*e, arena)),
-
         Expr::Cast {
             expr,
             data_type,
@@ -116,10 +109,6 @@ pub(crate) fn to_aexpr(expr: Expr, arena: &mut Arena<AExpr>) -> Node {
             function,
             options,
         },
-        Expr::Shift { input, periods } => AExpr::Shift {
-            input: to_aexpr(*input, arena),
-            periods,
-        },
         Expr::Window {
             function,
             partition_by,
@@ -452,9 +441,6 @@ pub(crate) fn node_to_expr(node: Node, expr_arena: &Arena<AExpr>) -> Expr {
     let expr = expr_arena.get(node).clone();
 
     match expr {
-        AExpr::Duplicated(node) => Expr::Duplicated(Box::new(node_to_expr(node, expr_arena))),
-        AExpr::IsUnique(node) => Expr::IsUnique(Box::new(node_to_expr(node, expr_arena))),
-        AExpr::Reverse(node) => Expr::Reverse(Box::new(node_to_expr(node, expr_arena))),
         AExpr::Explode(node) => Expr::Explode(Box::new(node_to_expr(node, expr_arena))),
         AExpr::Alias(expr, name) => {
             let exp = node_to_expr(expr, expr_arena);
@@ -471,18 +457,6 @@ pub(crate) fn node_to_expr(node: Node, expr_arena: &Arena<AExpr>) -> Expr {
                 right: Box::new(r),
             }
         }
-        AExpr::Not(expr) => {
-            let exp = node_to_expr(expr, expr_arena);
-            Expr::Not(Box::new(exp))
-        }
-        AExpr::IsNotNull(expr) => {
-            let exp = node_to_expr(expr, expr_arena);
-            Expr::IsNotNull(Box::new(exp))
-        }
-        AExpr::IsNull(expr) => {
-            let exp = node_to_expr(expr, expr_arena);
-            Expr::IsNull(Box::new(exp))
-        }
         AExpr::Cast {
             expr,
             data_type,
@@ -598,13 +572,6 @@ pub(crate) fn node_to_expr(node: Node, expr_arena: &Arena<AExpr>) -> Expr {
                 AggExpr::Count(Box::new(exp)).into()
             }
         },
-        AExpr::Shift { input, periods } => {
-            let e = node_to_expr(input, expr_arena);
-            Expr::Shift {
-                input: Box::new(e),
-                periods,
-            }
-        }
         AExpr::Ternary {
             predicate,
             truthy,
