@@ -4,8 +4,13 @@ use polars_arrow::utils::CustomIterTools;
 use polars_core::frame::groupby::GroupsProxy;
 use polars_core::prelude::*;
 use polars_core::POOL;
+#[cfg(feature = "parquet")]
+use polars_io::parquet::predicates::BatchStats;
+#[cfg(feature = "parquet")]
+use polars_io::predicates::StatsEvaluator;
 use rayon::prelude::*;
 
+use crate::dsl::function_expr::FunctionExpr;
 use crate::physical_plan::state::ExecutionState;
 use crate::prelude::*;
 
@@ -114,8 +119,14 @@ impl PhysicalExpr for ApplyExpr {
         if self.inputs.len() == 1 {
             let mut ac = self.inputs[0].evaluate_on_groups(df, groups, state)?;
 
-            match self.collect_groups {
-                ApplyOptions::ApplyGroups => {
+            match (state.overlapping_groups(), self.collect_groups) {
+                (_, ApplyOptions::ApplyList) => {
+                    let s = self.function.call_udf(&mut [ac.aggregated()])?;
+                    ac.with_series(s, true);
+                    Ok(ac)
+                }
+                // overlapping groups always take this branch as explode/flat_naive bloats data size
+                (_, ApplyOptions::ApplyGroups) | (true, _) => {
                     let s = ac.series();
 
                     // collection of empty list leads to a null dtype
@@ -152,31 +163,54 @@ impl PhysicalExpr for ApplyExpr {
                     ca.rename(&name);
                     Ok(self.finish_apply_groups(ac, ca))
                 }
-                ApplyOptions::ApplyFlat => {
+                (_, ApplyOptions::ApplyFlat) => {
                     // make sure the groups are updated because we are about to throw away
-                    // the series length information
+                    // the series' length information
+                    let set_update_groups = match ac.update_groups {
+                        UpdateGroups::WithSeriesLen => {
+                            ac.groups();
+                            true
+                        }
+                        UpdateGroups::WithSeriesLenOwned(_) => false,
+                        UpdateGroups::No | UpdateGroups::WithGroupsLen => false,
+                    };
+
                     if let UpdateGroups::WithSeriesLen = ac.update_groups {
                         ac.groups();
                     }
+
                     let input = ac.flat_naive().into_owned();
                     let input_len = input.len();
                     let s = self.function.call_udf(&mut [input])?;
 
                     check_map_output_len(input_len, s.len())?;
                     ac.with_series(s, false);
-                    Ok(ac)
-                }
-                ApplyOptions::ApplyList => {
-                    let s = self.function.call_udf(&mut [ac.aggregated()])?;
-                    ac.with_series(s, true);
+
+                    if set_update_groups {
+                        // The flat_naive orders by groups, so we must create new groups
+                        // not by series length as we don't have an agg_list, but by original
+                        // groups length
+                        ac.update_groups = UpdateGroups::WithGroupsLen;
+                    }
                     Ok(ac)
                 }
             }
         } else {
             let mut acs = self.prepare_multiple_inputs(df, groups, state)?;
 
-            match self.collect_groups {
-                ApplyOptions::ApplyGroups => {
+            match (state.overlapping_groups(), self.collect_groups) {
+                (_, ApplyOptions::ApplyList) => {
+                    let mut s = acs.iter_mut().map(|ac| ac.aggregated()).collect::<Vec<_>>();
+                    let s = self.function.call_udf(&mut s)?;
+                    // take the first aggregation context that as that is the input series
+                    let mut ac = acs.swap_remove(0);
+                    ac.with_update_groups(UpdateGroups::WithGroupsLen);
+                    ac.with_series(s, true);
+                    Ok(ac)
+                }
+
+                // overlapping groups always take this branch as explode bloats data size
+                (_, ApplyOptions::ApplyGroups) | (true, _) => {
                     let mut container = vec![Default::default(); acs.len()];
                     let name = acs[0].series().name().to_string();
 
@@ -210,7 +244,7 @@ impl PhysicalExpr for ApplyExpr {
                     let ac = self.finish_apply_groups(ac, ca);
                     Ok(ac)
                 }
-                ApplyOptions::ApplyFlat => {
+                (_, ApplyOptions::ApplyFlat) => {
                     let mut s = acs
                         .iter_mut()
                         .map(|ac| {
@@ -233,15 +267,6 @@ impl PhysicalExpr for ApplyExpr {
                     ac.with_series(s, false);
                     Ok(ac)
                 }
-                ApplyOptions::ApplyList => {
-                    let mut s = acs.iter_mut().map(|ac| ac.aggregated()).collect::<Vec<_>>();
-                    let s = self.function.call_udf(&mut s)?;
-                    // take the first aggregation context that as that is the input series
-                    let mut ac = acs.swap_remove(0);
-                    ac.with_update_groups(UpdateGroups::WithGroupsLen);
-                    ac.with_series(s, true);
-                    Ok(ac)
-                }
             }
         }
     }
@@ -251,4 +276,84 @@ impl PhysicalExpr for ApplyExpr {
     fn is_valid_aggregation(&self) -> bool {
         matches!(self.collect_groups, ApplyOptions::ApplyGroups)
     }
+    #[cfg(feature = "parquet")]
+    fn as_stats_evaluator(&self) -> Option<&dyn polars_io::predicates::StatsEvaluator> {
+        if matches!(
+            self.expr,
+            Expr::Function {
+                function: FunctionExpr::IsNull,
+                ..
+            }
+        ) {
+            Some(self)
+        } else {
+            None
+        }
+    }
+    fn as_partitioned_aggregator(&self) -> Option<&dyn PartitionedAggregation> {
+        if self.inputs.len() == 1 && matches!(self.collect_groups, ApplyOptions::ApplyFlat) {
+            Some(self)
+        } else {
+            None
+        }
+    }
+}
+
+#[cfg(feature = "parquet")]
+impl StatsEvaluator for ApplyExpr {
+    fn should_read(&self, stats: &BatchStats) -> Result<bool> {
+        if matches!(
+            self.expr,
+            Expr::Function {
+                function: FunctionExpr::IsNull,
+                ..
+            }
+        ) {
+            let root = expr_to_root_column_name(&self.expr)?;
+
+            let read = true;
+            let skip = false;
+
+            match stats.get_stats(&root).ok() {
+                Some(st) => match st.null_count() {
+                    Some(0) => Ok(skip),
+                    _ => Ok(read),
+                },
+                None => Ok(read),
+            }
+        } else {
+            Ok(true)
+        }
+    }
+}
+
+impl PartitionedAggregation for ApplyExpr {
+    fn evaluate_partitioned(
+        &self,
+        df: &DataFrame,
+        groups: &GroupsProxy,
+        state: &ExecutionState,
+    ) -> Result<Series> {
+        let a = self.inputs[0].as_partitioned_aggregator().unwrap();
+        let s = a.evaluate_partitioned(df, groups, state)?;
+
+        if self.allow_rename {
+            return self.function.call_udf(&mut [s]);
+        }
+        let in_name = s.name().to_string();
+        let mut out = self.function.call_udf(&mut [s])?;
+        if in_name != out.name() {
+            out.rename(&in_name);
+        }
+        Ok(out)
+    }
+
+    fn finalize(
+        &self,
+        partitioned: Series,
+        _groups: &GroupsProxy,
+        _state: &ExecutionState,
+    ) -> Result<Series> {
+        Ok(partitioned)
+    }
 }
