@@ -7,11 +7,7 @@ mod column;
 mod count;
 mod filter;
 mod group_iter;
-mod is_not_null;
-mod is_null;
 mod literal;
-mod not;
-mod shift;
 mod slice;
 mod sort;
 mod sortby;
@@ -21,17 +17,27 @@ mod window;
 
 use std::borrow::Cow;
 
+pub(crate) use aggregation::*;
+pub(crate) use alias::*;
+pub(crate) use apply::*;
+pub(crate) use binary::*;
+pub(crate) use cast::*;
+pub(crate) use column::*;
+pub(crate) use count::*;
+pub(crate) use filter::*;
+pub(crate) use literal::*;
 use polars_arrow::export::arrow::array::ListArray;
 use polars_arrow::trusted_len::PushUnchecked;
 use polars_arrow::utils::CustomIterTools;
 use polars_core::frame::groupby::GroupsProxy;
 use polars_core::prelude::*;
 use polars_io::predicates::PhysicalIoExpr;
-pub(crate) use {
-    aggregation::*, alias::*, apply::*, binary::*, cast::*, column::*, count::*, filter::*,
-    is_not_null::*, is_null::*, literal::*, not::*, shift::*, slice::*, sort::*, sortby::*,
-    take::*, ternary::*, window::*,
-};
+pub(crate) use slice::*;
+pub(crate) use sort::*;
+pub(crate) use sortby::*;
+pub(crate) use take::*;
+pub(crate) use ternary::*;
+pub(crate) use window::*;
 
 use crate::physical_plan::state::ExecutionState;
 use crate::prelude::*;
@@ -494,7 +500,18 @@ impl<'a> AggregationContext<'a> {
     pub(crate) fn flat_naive(&self) -> Cow<'_, Series> {
         match &self.state {
             AggState::NotAggregated(s) => Cow::Borrowed(s),
-            AggState::AggregatedList(s) => Cow::Owned(s.explode().unwrap()),
+            AggState::AggregatedList(s) => {
+                #[cfg(debug_assertions)]
+                {
+                    // panic so we find cases where we accidentally explode overlapping groups
+                    // we don't want this as this can create a lot of data
+                    if let GroupsProxy::Slice { rolling: true, .. } = self.groups.as_ref() {
+                        panic!("implementation error, polars should not hit this branch for overlapping groups")
+                    }
+                }
+
+                Cow::Owned(s.explode().unwrap())
+            }
             AggState::AggregatedFlat(s) => Cow::Borrowed(s),
             AggState::Literal(s) => Cow::Borrowed(s),
         }
