@@ -122,13 +122,6 @@ impl PhysicalPlanner {
                     node_to_expr(expression, expr_arena),
                 )))
             }
-            Not(expr) => {
-                let phys_expr = self.create_physical_expr(expr, ctxt, expr_arena)?;
-                Ok(Arc::new(NotExpr::new(
-                    phys_expr,
-                    node_to_expr(expression, expr_arena),
-                )))
-            }
             Alias(expr, name) => {
                 let phys_expr = self.create_physical_expr(expr, ctxt, expr_arena)?;
                 Ok(Arc::new(AliasExpr::new(
@@ -137,20 +130,6 @@ impl PhysicalPlanner {
                     node_to_expr(expression, expr_arena),
                 )))
             }
-            IsNull(expr) => {
-                let phys_expr = self.create_physical_expr(expr, ctxt, expr_arena)?;
-                Ok(Arc::new(IsNullExpr::new(
-                    phys_expr,
-                    node_to_expr(expression, expr_arena),
-                )))
-            }
-            IsNotNull(expr) => {
-                let phys_expr = self.create_physical_expr(expr, ctxt, expr_arena)?;
-                Ok(Arc::new(IsNotNullExpr::new(
-                    phys_expr,
-                    node_to_expr(expression, expr_arena),
-                )))
-            }
             Agg(agg) => {
                 match agg {
                     AAggExpr::Min(expr) => {
@@ -530,14 +509,6 @@ impl PhysicalPlanner {
                     allow_rename: options.allow_rename,
                 }))
             }
-            Shift { input, periods } => {
-                let input = self.create_physical_expr(input, ctxt, expr_arena)?;
-                Ok(Arc::new(phys_expr::ShiftExpr {
-                    input,
-                    periods,
-                    expr: node_to_expr(expression, expr_arena),
-                }))
-            }
             Slice {
                 input,
                 offset,
@@ -553,45 +524,6 @@ impl PhysicalPlanner {
                     expr: node_to_expr(expression, expr_arena),
                 }))
             }
-            Reverse(expr) => {
-                let input = self.create_physical_expr(expr, ctxt, expr_arena)?;
-                let function = SpecialEq::new(Arc::new(move |s: &mut [Series]| {
-                    let s = std::mem::take(&mut s[0]);
-                    Ok(s.reverse())
-                }) as Arc<dyn SeriesUdf>);
-                Ok(Arc::new(ApplyExpr::new_minimal(
-                    vec![input],
-                    function,
-                    node_to_expr(expression, expr_arena),
-                    ApplyOptions::ApplyGroups,
-                )))
-            }
-            Duplicated(expr) => {
-                let input = self.create_physical_expr(expr, ctxt, expr_arena)?;
-                let function = SpecialEq::new(Arc::new(move |s: &mut [Series]| {
-                    let s = std::mem::take(&mut s[0]);
-                    s.is_duplicated().map(|ca| ca.into_series())
-                }) as Arc<dyn SeriesUdf>);
-                Ok(Arc::new(ApplyExpr::new_minimal(
-                    vec![input],
-                    function,
-                    node_to_expr(expression, expr_arena),
-                    ApplyOptions::ApplyGroups,
-                )))
-            }
-            IsUnique(expr) => {
-                let input = self.create_physical_expr(expr, ctxt, expr_arena)?;
-                let function = SpecialEq::new(Arc::new(move |s: &mut [Series]| {
-                    let s = std::mem::take(&mut s[0]);
-                    s.is_unique().map(|ca| ca.into_series())
-                }) as Arc<dyn SeriesUdf>);
-                Ok(Arc::new(ApplyExpr::new_minimal(
-                    vec![input],
-                    function,
-                    node_to_expr(expression, expr_arena),
-                    ApplyOptions::ApplyGroups,
-                )))
-            }
             Explode(expr) => {
                 let input = self.create_physical_expr(expr, ctxt, expr_arena)?;
                 let function = SpecialEq::new(Arc::new(move |s: &mut [Series]| {
@@ -602,7 +534,7 @@ impl PhysicalPlanner {
                     vec![input],
                     function,
                     node_to_expr(expression, expr_arena),
-                    ApplyOptions::ApplyFlat,
+                    ApplyOptions::ApplyGroups,
                 )))
             }
             Wildcard => panic!("should be no wildcard at this point"),
