@@ -25,17 +25,17 @@ pub struct RollingGroupOptions {
 
 pub(crate) use polars_ops::prelude::*;
 
-pub use crate::{
-    dsl::*,
-    frame::*,
-    logical_plan::{
-        optimizer::{type_coercion::TypeCoercionRule, Optimize, *},
-        options::*,
-        *,
-    },
-    physical_plan::{expressions::*, planner::PhysicalPlanner, Executor},
-};
-pub(crate) use crate::{
-    logical_plan::{aexpr::*, alp::*, conversion::*, iterator::*},
-    utils::*,
-};
+pub use crate::dsl::*;
+pub use crate::frame::*;
+pub(crate) use crate::logical_plan::aexpr::*;
+pub(crate) use crate::logical_plan::alp::*;
+pub(crate) use crate::logical_plan::conversion::*;
+pub(crate) use crate::logical_plan::iterator::*;
+pub use crate::logical_plan::optimizer::type_coercion::TypeCoercionRule;
+pub use crate::logical_plan::optimizer::{Optimize, *};
+pub use crate::logical_plan::options::*;
+pub use crate::logical_plan::*;
+pub use crate::physical_plan::expressions::*;
+pub use crate::physical_plan::planner::PhysicalPlanner;
+pub use crate::physical_plan::Executor;
+pub(crate) use crate::utils::*;
