@@ -12,6 +12,7 @@ from polars.datatypes import (
     Datetime,
     Duration,
     PolarsDataType,
+    UInt32,
     is_polars_dtype,
     py_type_to_dtype,
 )
@@ -41,6 +42,7 @@ try:
     from polars.polars import py_datetime, py_duration
     from polars.polars import repeat as _repeat
     from polars.polars import spearman_rank_corr as pyspearman_rank_corr
+    from polars.polars import sum_exprs as _sum_exprs
 
     _DOCUMENTING = False
 except ImportError:
@@ -380,24 +382,99 @@ def sum(column: pli.Series) -> int | float:
 
 def sum(column: str | list[pli.Expr | str] | pli.Series | pli.Expr) -> pli.Expr | Any:
     """
-    Get the sum value.
+    Sum values in a column/Series, or horizontally across list of columns/expressions.
 
+    ``pl.sum(str)`` is syntactic sugar for:
+
+    >>> pl.col(str).sum()  # doctest: +SKIP
+
+    ``pl.sum(list)`` is syntactic sugar for:
+
+    >>> pl.fold(pl.lit(0), lambda x, y: x + y, list).alias("sum")  # doctest: +SKIP
+
+    Parameters
+    ----------
     column
-        Column(s) to be used in aggregation. Will lead to different behavior based on
-        the input:
-        - Union[str, Series] -> aggregate the sum value of that column.
-        - List[Expr] -> aggregate the sum value horizontally.
+        Column(s) to be used in aggregation.
+        This can be:
+
+        - a column name, or Series -> aggregate the sum value of that column/Series.
+        - a List[Expr] -> aggregate the sum value horizontally across the Expr result.
+
+    Examples
+    --------
+    >>> df = pl.DataFrame(
+    ...     {
+    ...         "a": [1, 2],
+    ...         "b": [3, 4],
+    ...         "c": [5, 6],
+    ...     }
+    ... )
+    >>> df
+    shape: (2, 3)
+    ┌─────┬─────┬─────┐
+    │ a   ┆ b   ┆ c   │
+    │ --- ┆ --- ┆ --- │
+    │ i64 ┆ i64 ┆ i64 │
+    ╞═════╪═════╪═════╡
+    │ 1   ┆ 3   ┆ 5   │
+    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤
+    │ 2   ┆ 4   ┆ 6   │
+    └─────┴─────┴─────┘
+
+    Sum a column by name:
+
+    >>> df.select(pl.sum("a"))
+    shape: (1, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 3   │
+    └─────┘
+
+    Sum a list of columns/expressions horizontally:
+
+    >>> df.with_column(pl.sum(["a", "c"]))
+    shape: (2, 4)
+    ┌─────┬─────┬─────┬─────┐
+    │ a   ┆ b   ┆ c   ┆ sum │
+    │ --- ┆ --- ┆ --- ┆ --- │
+    │ i64 ┆ i64 ┆ i64 ┆ i64 │
+    ╞═════╪═════╪═════╪═════╡
+    │ 1   ┆ 3   ┆ 5   ┆ 6   │
+    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤
+    │ 2   ┆ 4   ┆ 6   ┆ 8   │
+    └─────┴─────┴─────┴─────┘
+
+    Sum a series:
+
+    >>> pl.sum(df.get_column("a"))
+    3
+
+    To aggregate the sums for more than one column/expression use ``pl.col(list).sum()``
+    instead:
+
+    >>> df.select(pl.col(["a", "c"]).sum())
+    shape: (1, 2)
+    ┌─────┬─────┐
+    │ a   ┆ c   │
+    │ --- ┆ --- │
+    │ i64 ┆ i64 │
+    ╞═════╪═════╡
+    │ 3   ┆ 11  │
+    └─────┴─────┘
 
     """
     if isinstance(column, pli.Series):
         return column.sum()
     elif isinstance(column, list):
-        first = column[0]
-        if isinstance(first, str):
-            first = col(first)
-        return fold(first, lambda a, b: a + b, column[1:]).alias("sum")
+        exprs = pli.selection_to_pyexpr_list(column)
+        return pli.wrap_expr(_sum_exprs(exprs))
     elif isinstance(column, pli.Expr):
-        return fold(lit(0), lambda a, b: a + b, column).alias("sum")
+        # use u32 as that is not cast to float as eagerly
+        return fold(lit(0).cast(UInt32), lambda a, b: a + b, column).alias("sum")
     else:
         return col(column).sum()
 
@@ -598,7 +675,9 @@ def tail(column: str | pli.Series, n: int = 10) -> pli.Expr | pli.Series:
     return col(column).tail(n)
 
 
-def lit(value: Any, dtype: type[DataType] | None = None) -> pli.Expr:
+def lit(
+    value: Any, dtype: type[DataType] | None = None, allow_object: bool = False
+) -> pli.Expr:
     """
     Return an expression representing a literal value.
 
@@ -608,6 +687,10 @@ def lit(value: Any, dtype: type[DataType] | None = None) -> pli.Expr:
         Value that should be used as a `literal`.
     dtype
         Optionally define a dtype.
+    allow_object
+        If type is unknown use an 'object' type.
+        By default, we will raise a `ValueException`
+        if the type is unknown.
 
     Examples
     --------
@@ -648,7 +731,7 @@ def lit(value: Any, dtype: type[DataType] | None = None) -> pli.Expr:
     elif isinstance(value, pli.Series):
         name = value.name
         value = value._s
-        e = pli.wrap_expr(pylit(value))
+        e = pli.wrap_expr(pylit(value, allow_object))
         if name == "":
             return e
         return e.alias(name)
@@ -657,7 +740,7 @@ def lit(value: Any, dtype: type[DataType] | None = None) -> pli.Expr:
         return lit(pli.Series("", value))
 
     if dtype:
-        return pli.wrap_expr(pylit(value)).cast(dtype)
+        return pli.wrap_expr(pylit(value, allow_object)).cast(dtype)
 
     try:
         # numpy literals like np.float32(0) have item/dtype
@@ -679,7 +762,7 @@ def lit(value: Any, dtype: type[DataType] | None = None) -> pli.Expr:
     except AttributeError:
         item = value
 
-    return pli.wrap_expr(pylit(item))
+    return pli.wrap_expr(pylit(item, allow_object))
 
 
 def spearman_rank_corr(a: str | pli.Expr, b: str | pli.Expr, ddof: int = 1) -> pli.Expr:
