@@ -1,7 +1,3 @@
-"""
-Module containing all expressions and classes needed for lazy computation/query
-execution.
-"""
 from __future__ import annotations
 
 import os
@@ -80,7 +76,7 @@ class LazyFrame:
         return self
 
     @classmethod
-    def scan_csv(
+    def _scan_csv(
         cls: type[LDF],
         file: str,
         has_header: bool = True,
@@ -147,7 +143,7 @@ class LazyFrame:
         return self
 
     @classmethod
-    def scan_parquet(
+    def _scan_parquet(
         cls: type[LDF],
         file: str,
         n_rows: int | None = None,
@@ -191,7 +187,7 @@ class LazyFrame:
         return self
 
     @classmethod
-    def scan_ipc(
+    def _scan_ipc(
         cls: type[LDF],
         file: str | Path,
         n_rows: int | None = None,
@@ -203,9 +199,14 @@ class LazyFrame:
         memory_map: bool = True,
     ) -> LDF:
         """
+        Lazily read from an Arrow IPC (Feather v2) file.
+
+        Use ``pl.scan_ipc`` to dispatch to this method.
+
         See Also
         --------
-        scan_parquet, scan_csv
+        polars.io.scan_ipc
+
         """
         if isinstance(file, (str, Path)):
             file = format_path(file)
@@ -231,7 +232,7 @@ class LazyFrame:
         return self
 
     @classmethod
-    def scan_ndjson(
+    def _scan_ndjson(
         cls: type[LDF],
         file: str,
         infer_schema_length: int | None = None,
@@ -267,9 +268,12 @@ class LazyFrame:
     @classmethod
     def from_json(cls, json: str) -> LazyFrame:
         """
+        Create a DataFrame from a JSON string.
+
         See Also
         --------
         read_json
+
         """
         f = StringIO(json)
         return cls.read_json(f)
@@ -294,6 +298,133 @@ class LazyFrame:
 
         return wrap_ldf(PyLazyFrame.read_json(file))
 
+    @classmethod
+    def _scan_python_function(
+        cls, schema: pa.schema | dict[str, type[DataType]], scan_fn: bytes
+    ) -> LazyFrame:
+        self = cls.__new__(cls)
+        if isinstance(schema, dict):
+            self._ldf = PyLazyFrame.scan_from_python_function_pl_schema(
+                [(name, dt) for name, dt in schema.items()], scan_fn
+            )
+        else:
+            self._ldf = PyLazyFrame.scan_from_python_function_arrow_schema(
+                list(schema), scan_fn
+            )
+        return self
+
+    @property
+    def columns(self) -> list[str]:
+        """
+        Get or set column names.
+
+        Examples
+        --------
+        >>> df = (
+        ...     pl.DataFrame(
+        ...         {
+        ...             "foo": [1, 2, 3],
+        ...             "bar": [6, 7, 8],
+        ...             "ham": ["a", "b", "c"],
+        ...         }
+        ...     )
+        ...     .lazy()
+        ...     .select(["foo", "bar"])
+        ... )
+
+        >>> df.columns
+        ['foo', 'bar']
+
+        """
+        return self._ldf.columns()
+
+    @property
+    def dtypes(self) -> list[type[DataType]]:
+        """
+        Get dtypes of columns in LazyFrame.
+
+        Examples
+        --------
+        >>> lf = pl.DataFrame(
+        ...     {
+        ...         "foo": [1, 2, 3],
+        ...         "bar": [6.0, 7.0, 8.0],
+        ...         "ham": ["a", "b", "c"],
+        ...     }
+        ... ).lazy()
+        >>> lf.dtypes
+        [<class 'polars.datatypes.Int64'>, <class 'polars.datatypes.Float64'>, <class 'polars.datatypes.Utf8'>]
+
+        See Also
+        --------
+        schema : Returns a {colname:dtype} mapping.
+
+        """  # noqa: E501
+        return self._ldf.dtypes()
+
+    @property
+    def schema(self) -> Schema:
+        """
+        Get a dict[column name, DataType].
+
+        Examples
+        --------
+        >>> lf = pl.DataFrame(
+        ...     {
+        ...         "foo": [1, 2, 3],
+        ...         "bar": [6.0, 7.0, 8.0],
+        ...         "ham": ["a", "b", "c"],
+        ...     }
+        ... ).lazy()
+        >>> lf.schema
+        {'foo': <class 'polars.datatypes.Int64'>, 'bar': <class 'polars.datatypes.Float64'>, 'ham': <class 'polars.datatypes.Utf8'>}
+
+        """  # noqa: E501
+        return self._ldf.schema()
+
+    def __contains__(self: LDF, key: str) -> bool:
+        return key in self.columns
+
+    def __copy__(self: LDF) -> LDF:
+        return self.clone()
+
+    def __deepcopy__(self: LDF, memo: None = None) -> LDF:
+        return self.clone()
+
+    def __getitem__(self: LDF, item: int | range | slice) -> LazyFrame:
+        if not isinstance(item, slice):
+            raise TypeError(
+                "'LazyFrame' object is not subscriptable (aside from slicing). Use"
+                " 'select()' or 'filter()' instead."
+            )
+        return LazyPolarsSlice(self).apply(item)
+
+    def __str__(self) -> str:
+        return f"""\
+naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
+
+{self.describe_plan()}\
+"""
+
+    def _repr_html_(self) -> str:
+        try:
+            dot = self._ldf.to_dot(optimized=False)
+            svg = subprocess.check_output(
+                ["dot", "-Nshape=box", "-Tsvg"], input=f"{dot}".encode()
+            )
+            return (
+                "<h4>NAIVE QUERY PLAN</h4><p>run <b>LazyFrame.show_graph()</b> to see"
+                f" the optimized version</p>{svg.decode()}"
+            )
+        except Exception:
+            insert = self.describe_plan().replace("\n", "<p></p>")
+
+            return f"""\
+<i>naive plan: (run <b>LazyFrame.describe_optimized_plan()</b> to see the optimized plan)</i>
+    <p></p>
+    <div>{insert}</div>\
+"""  # noqa: E501
+
     @overload
     def write_json(
         self,
@@ -359,32 +490,6 @@ class LazyFrame:
             self._ldf.write_json(file)
         return None
 
-    @classmethod
-    def _scan_python_function(
-        cls, schema: pa.schema | dict[str, type[DataType]], scan_fn: bytes
-    ) -> LazyFrame:
-        self = cls.__new__(cls)
-        if isinstance(schema, dict):
-            self._ldf = PyLazyFrame.scan_from_python_function_pl_schema(
-                [(name, dt) for name, dt in schema.items()], scan_fn
-            )
-        else:
-            self._ldf = PyLazyFrame.scan_from_python_function_arrow_schema(
-                list(schema), scan_fn
-            )
-        return self
-
-    def __getitem__(self: LDF, item: int | range | slice) -> LazyFrame:
-        if not isinstance(item, slice):
-            raise TypeError(
-                "'LazyFrame' object is not subscriptable (aside from slicing). Use"
-                " 'select()' or 'filter()' instead."
-            )
-        return LazyPolarsSlice(self).apply(item)
-
-    def __contains__(self: LDF, key: str) -> bool:
-        return key in self.columns
-
     def pipe(self, func: Callable[..., Any], *args: Any, **kwargs: Any) -> Any:
         """
         Apply a function on Self.
@@ -423,32 +528,6 @@ class LazyFrame:
         """
         return func(self, *args, **kwargs)
 
-    def _repr_html_(self) -> str:
-        try:
-            dot = self._ldf.to_dot(optimized=False)
-            svg = subprocess.check_output(
-                ["dot", "-Nshape=box", "-Tsvg"], input=f"{dot}".encode()
-            )
-            return (
-                "<h4>NAIVE QUERY PLAN</h4><p>run <b>LazyFrame.show_graph()</b> to see"
-                f" the optimized version</p>{svg.decode()}"
-            )
-        except Exception:
-            insert = self.describe_plan().replace("\n", "<p></p>")
-
-            return f"""\
-<i>naive plan: (run <b>LazyFrame.describe_optimized_plan()</b> to see the optimized plan)</i>
-    <p></p>
-    <div>{insert}</div>\
-"""  # noqa: E501
-
-    def __str__(self) -> str:
-        return f"""\
-naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
-
-{self.describe_plan()}\
-"""
-
     def describe_plan(self) -> str:
         """Create a string representation of the unoptimized query plan."""
         return self._ldf.describe_plan()
@@ -546,9 +625,13 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
 
     def inspect(self: LDF, fmt: str = "{}") -> LDF:
         """
+        Inspect a node in the computation graph.
+
         Print the value that this node in the computation graph evaluates to and passes
         on the value.
 
+        Examples
+        --------
         >>> df = pl.DataFrame({"foo": [1, 1, -2, 3]}).lazy()
         >>> (
         ...     df.select(
@@ -576,11 +659,13 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         nulls_last: bool = False,
     ) -> LDF:
         """
-        Sort the DataFrame by:
+        Sort the DataFrame.
 
-            - A single column name
-            - An expression
-            - Multiple expressions
+        Sorting can be done by:
+
+        - A single column name
+        - An expression
+        - Multiple expressions
 
         Parameters
         ----------
@@ -671,6 +756,8 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         slice_pushdown: bool = True,
     ) -> pli.DataFrame:
         """
+        Collect a small number of rows for debugging purposes.
+
         Fetch is like a :func:`collect` operation, but it overwrites the number of rows
         read by every scan operation. This is a utility that helps debug a query on a
         smaller number of rows.
@@ -735,75 +822,6 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         """
         return self
 
-    @property
-    def columns(self) -> list[str]:
-        """
-        Get or set column names.
-
-        Examples
-        --------
-        >>> df = (
-        ...     pl.DataFrame(
-        ...         {
-        ...             "foo": [1, 2, 3],
-        ...             "bar": [6, 7, 8],
-        ...             "ham": ["a", "b", "c"],
-        ...         }
-        ...     )
-        ...     .lazy()
-        ...     .select(["foo", "bar"])
-        ... )
-
-        >>> df.columns
-        ['foo', 'bar']
-
-        """
-        return self._ldf.columns()
-
-    @property
-    def dtypes(self) -> list[type[DataType]]:
-        """
-        Get dtypes of columns in LazyFrame.
-
-        Examples
-        --------
-        >>> lf = pl.DataFrame(
-        ...     {
-        ...         "foo": [1, 2, 3],
-        ...         "bar": [6.0, 7.0, 8.0],
-        ...         "ham": ["a", "b", "c"],
-        ...     }
-        ... ).lazy()
-        >>> lf.dtypes
-        [<class 'polars.datatypes.Int64'>, <class 'polars.datatypes.Float64'>, <class 'polars.datatypes.Utf8'>]
-
-        See Also
-        --------
-        schema : Returns a {colname:dtype} mapping.
-
-        """  # noqa: E501
-        return self._ldf.dtypes()
-
-    @property
-    def schema(self) -> Schema:
-        """
-        Get a dict[column name, DataType]
-
-        Examples
-        --------
-        >>> lf = pl.DataFrame(
-        ...     {
-        ...         "foo": [1, 2, 3],
-        ...         "bar": [6.0, 7.0, 8.0],
-        ...         "ham": ["a", "b", "c"],
-        ...     }
-        ... ).lazy()
-        >>> lf.schema
-        {'foo': <class 'polars.datatypes.Int64'>, 'bar': <class 'polars.datatypes.Float64'>, 'ham': <class 'polars.datatypes.Utf8'>}
-
-        """  # noqa: E501
-        return self._ldf.schema()
-
     def cache(self: LDF) -> LDF:
         """Cache the result once the execution of the physical plan hits this node."""
         return self._from_pyldf(self._ldf.cache())
@@ -851,12 +869,6 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         """
         return self._from_pyldf(self._ldf.clone())
 
-    def __copy__(self: LDF) -> LDF:
-        return self.clone()
-
-    def __deepcopy__(self: LDF, memo: None = None) -> LDF:
-        return self.clone()
-
     def filter(self: LDF, predicate: pli.Expr | str | pli.Series | list[bool]) -> LDF:
         """
         Filter the rows in the DataFrame based on a predicate expression.
@@ -1009,18 +1021,14 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         by: str | list[str] | pli.Expr | list[pli.Expr] | None = None,
     ) -> LazyGroupBy[LDF]:
         """
-        Create rolling groups based on a time column (or index value of type Int32,
-        Int64).
+        Create rolling groups based on a time column.
+
+        Also works for index values of type Int32 or Int64.
 
         Different from a rolling groupby the windows are now determined by the
         individual values and are not of constant intervals. For constant intervals use
         *groupby_dynamic*
 
-        .. seealso::
-
-            groupby_dynamic
-
-
         The `period` and `offset` arguments are created with
         the following string language:
 
@@ -1064,6 +1072,10 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         by
             Also group by this column/these columns
 
+        See Also
+        --------
+        groupby_dynamic
+
         Examples
         --------
         >>> dates = [
@@ -1134,10 +1146,6 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         window could be seen as a rolling window, with a window size determined by
         dates/times/values instead of slots in the DataFrame.
 
-        .. seealso::
-
-            groupby_rolling
-
         A window is defined by:
 
         - every: interval of the window
@@ -1196,6 +1204,10 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         by
             Also group by this column/these columns
 
+        See Also
+        --------
+        groupby_rolling
+
         """
         if offset is None:
             if period is None:
@@ -1233,8 +1245,10 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         force_parallel: bool = False,
     ) -> LDF:
         """
-        Perform an asof join. This is similar to a left-join except that we
-        match on nearest key rather than equal keys.
+        Perform an asof join.
+
+        This is similar to a left-join except that we match on nearest key rather than
+        equal keys.
 
         Both DataFrames must be sorted by the join_asof key.
 
@@ -1688,8 +1702,7 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
 
     def shift(self: LDF, periods: int) -> LDF:
         """
-        Shift the values by a given period and fill the parts that will be empty due to
-        this operation with `Nones`.
+        Shift the values by a given period.
 
         Parameters
         ----------
@@ -1740,8 +1753,7 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         fill_value: pli.Expr | int | str | float,
     ) -> LDF:
         """
-        Shift the values by a given period and fill the parts that will be empty due to
-        this operation with the result of the `fill_value` expression.
+        Shift the values by a given period and fill the resulting null values.
 
         Parameters
         ----------
@@ -1893,10 +1905,6 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         """
         Add a column at index 0 that counts the rows.
 
-        .. warning::
-            This can have a negative effect on query performance.
-            This may, for instance, block predicate pushdown optimization.
-
         Parameters
         ----------
         name
@@ -1904,6 +1912,11 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         offset
             Start the row count at this offset.
 
+        Warnings
+        --------
+        This can have a negative effect on query performance.
+        This may, for instance, block predicate pushdown optimization.
+
         Examples
         --------
         >>> df = pl.DataFrame(
@@ -1977,15 +1990,16 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         """
         Fill floating point NaN values.
 
-        .. warning::
-            Note that floating point NaN (Not a Number) are not missing values!
-            To replace missing values, use :func:`fill_null` instead.
-
         Parameters
         ----------
         fill_value
             Value to fill the NaN values with.
 
+        Warnings
+        --------
+        Note that floating point NaN (Not a Number) are not missing values!
+        To replace missing values, use :func:`fill_null` instead.
+
         """
         if not isinstance(fill_value, pli.Expr):
             fill_value = pli.lit(fill_value)
@@ -2107,6 +2121,7 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
     ) -> LDF:
         """
         Drop duplicate rows from this DataFrame.
+
         Note that this fails if there is a column of type `List` in the DataFrame or
         subset.
 
@@ -2222,8 +2237,9 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         value_name: str | None = None,
     ) -> LDF:
         """
-        Unpivot a DataFrame from wide to long format, optionally leaving identifiers
-        set.
+        Unpivot a DataFrame from wide to long format.
+
+        Optionally leaves identifiers set.
 
         This function is useful to massage a DataFrame into a format where one or more
         columns are identifier variables (id_vars), while all other columns, considered
@@ -2295,20 +2311,9 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         validate_output_schema: bool = True,
     ) -> LDF:
         """
-        Apply a custom function. It is important that the function returns a Polars
-        DataFrame.
+        Apply a custom function.
 
-        .. warning::
-            The ``schema`` of a `LazyFrame` must always be correct.
-            It is up to the caller of this function to ensure that
-            this invariant is uphold.
-
-        .. warning::
-            It is important that the optimization flags are correct.
-            If the custom function for instance does an aggregation
-            of a column, ``predicate_pushdown`` should not be allowed,
-            as this prunes rows and will influence your aggregation
-            results.
+        It is important that the function returns a Polars DataFrame.
 
         Parameters
         ----------
@@ -2323,14 +2328,22 @@ naive plan: (run LazyFrame.describe_optimized_plan() to see the optimized plan)
         no_optimizations
             Turn off all optimizations past this point.
         schema
-            Output schema of the function, if set to ``None``
-            we assume that the schema will remain unchanged
-            by the applied function.
+            Output schema of the function, if set to ``None`` we assume that the schema
+            will remain unchanged by the applied function.
         validate_output_schema
-            It is paramount that polars' schema is correct. This flag
-            will ensure that the output schema of this function will
-            be checked with the expected schema. Setting this to ``False``
-            will not do this check, but may lead to hard to debug bugs.
+            It is paramount that polars' schema is correct. This flag will ensure that
+            the output schema of this function will be checked with the expected schema.
+            Setting this to ``False`` will not do this check, but may lead to hard to
+            debug bugs.
+
+        Warnings
+        --------
+        The ``schema`` of a `LazyFrame` must always be correct. It is up to the caller
+        of this function to ensure that this invariant is upheld.
+
+        It is important that the optimization flags are correct. If the custom function
+        for instance does an aggregation of a column, ``predicate_pushdown`` should not
+        be allowed, as this prunes rows and will influence your aggregation results.
 
         """
         if no_optimizations:
