@@ -13,11 +13,10 @@ use polars::io::RowCount;
 use polars::prelude::*;
 use polars_core::export::arrow::datatypes::IntegerType;
 use polars_core::frame::explode::MeltArgs;
-use polars_core::frame::groupby::PivotAgg;
 use polars_core::frame::ArrowChunk;
 use polars_core::prelude::QuantileInterpolOptions;
 use polars_core::utils::arrow::compute::cast::CastOptions;
-use polars_core::utils::get_supertype;
+use polars_core::utils::try_get_supertype;
 use polars_lazy::frame::pivot::{pivot, pivot_stable};
 use pyo3::exceptions::PyRuntimeError;
 use pyo3::prelude::*;
@@ -430,7 +429,10 @@ impl PyDataFrame {
         date_format: Option<String>,
         time_format: Option<String>,
         float_precision: Option<usize>,
+        null_value: Option<String>,
     ) -> PyResult<()> {
+        let null = null_value.unwrap_or(String::new());
+
         if let Ok(s) = py_f.extract::<&str>(py) {
             let f = std::fs::File::create(s).unwrap();
             // no need for a buffered writer, because the csv writer does internal buffering
@@ -443,6 +445,7 @@ impl PyDataFrame {
                 .with_date_format(date_format)
                 .with_time_format(time_format)
                 .with_float_precision(float_precision)
+                .with_null_value(null)
                 .finish(&mut self.df)
                 .map_err(PyPolarsErr::from)?;
         } else {
@@ -456,6 +459,7 @@ impl PyDataFrame {
                 .with_date_format(date_format)
                 .with_time_format(time_format)
                 .with_float_precision(float_precision)
+                .with_null_value(null)
                 .finish(&mut self.df)
                 .map_err(PyPolarsErr::from)?;
         }
@@ -540,7 +544,7 @@ impl PyDataFrame {
             match st {
                 None => st = Some(dt_i.clone()),
                 Some(ref mut st) => {
-                    *st = get_supertype(st, dt_i).ok()?;
+                    *st = try_get_supertype(st, dt_i).ok()?;
                 }
             }
         }
@@ -1058,30 +1062,6 @@ impl PyDataFrame {
         Ok(PyDataFrame::new(df))
     }
 
-    pub fn pivot(
-        &self,
-        by: Vec<String>,
-        pivot_column: Vec<String>,
-        values_column: Vec<String>,
-        agg: Wrap<PivotAgg>,
-    ) -> PyResult<Self> {
-        let mut gb = self.df.groupby(&by).map_err(PyPolarsErr::from)?;
-        let pivot = gb.pivot(pivot_column, values_column);
-        let df = match agg.0 {
-            PivotAgg::First => pivot.first(),
-            PivotAgg::Min => pivot.min(),
-            PivotAgg::Max => pivot.max(),
-            PivotAgg::Mean => pivot.mean(),
-            PivotAgg::Median => pivot.median(),
-            PivotAgg::Sum => pivot.sum(),
-            PivotAgg::Count => pivot.count(),
-            PivotAgg::Last => pivot.last(),
-            PivotAgg::Expr(_) => unimplemented!(),
-        };
-        let df = df.map_err(PyPolarsErr::from)?;
-        Ok(PyDataFrame::new(df))
-    }
-
     pub fn clone(&self) -> Self {
         PyDataFrame::new(self.df.clone())
     }
@@ -1104,31 +1084,6 @@ impl PyDataFrame {
         Ok(PyDataFrame::new(df))
     }
 
-    pub fn pivot2(
-        &self,
-        values: Vec<String>,
-        index: Vec<String>,
-        columns: Vec<String>,
-        aggregate_fn: Wrap<PivotAgg>,
-        maintain_order: bool,
-        sort_columns: bool,
-    ) -> PyResult<Self> {
-        let fun = match maintain_order {
-            true => DataFrame::pivot_stable,
-            false => DataFrame::pivot,
-        };
-        let df = fun(
-            &self.df,
-            values,
-            index,
-            columns,
-            aggregate_fn.0,
-            sort_columns,
-        )
-        .map_err(PyPolarsErr::from)?;
-        Ok(PyDataFrame::new(df))
-    }
-
     #[cfg(feature = "pivot")]
     pub fn pivot_expr(
         &self,
@@ -1331,7 +1286,7 @@ impl PyDataFrame {
         self.df.shrink_to_fit();
     }
 
-    pub fn hash_rows(&self, k0: u64, k1: u64, k2: u64, k3: u64) -> PyResult<PySeries> {
+    pub fn hash_rows(&mut self, k0: u64, k1: u64, k2: u64, k3: u64) -> PyResult<PySeries> {
         let hb = ahash::RandomState::with_seeds(k0, k1, k2, k3);
         let hash = self.df.hash_rows(Some(hb)).map_err(PyPolarsErr::from)?;
         Ok(hash.into_series().into())
